#!/usr/bin/env python

# Include python modules
from lxml import etree
from ncclient import manager

# Request information
username = "developer"
password = "C1sco12345"
hostname = "sandbox-iosxe-recomm-1.cisco.com"
port = "830"

# Make NETCONF connection
device = manager.connect(host=hostname, port=port, 
	username=username, password=password,
	hostkey_verify=False, device_params={},
	allow_agent=False, look_for_keys=False)

# Define XML Filter Request
xml_filter = """
    <native xmlns="http://cisco.com/ns/yang/Cisco-IOS-XE-native">
     <version />
     <hostname />
    </native>
"""

# Request data from device with XML Filter
netconf_response = device.get(('subtree', xml_filter))

# Print the XML Response
print('XML Response:')
print('-' * 80)
print(etree.tostring(netconf_response.data_ele, pretty_print=True).decode('utf-8'))

# Define XML Namespace for Find
ns_find = {
  None: "http://cisco.com/ns/yang/Cisco-IOS-XE-native",
}

# Find the elements we want values
device_hostname = netconf_response.data.find(".//hostname", namespaces=ns_find).text
device_version = netconf_response.data.find(".//version", namespaces=ns_find).text

# Print the results
print('-' * 80)
print(f'Hostname: {device_hostname}')
print(f'Version: {device_version}')
print("\n")
